#include "genpari.h"

GEN ploth(entree *ep, GEN a, GEN b, char *ch, long prec)
{
  return gnil;
}

GEN ploth2(entree *ep, GEN a, GEN b, char *ch, long prec)
{
  return gnil;
}

GEN plothraw(GEN listx, GEN listy)
{
  return gnil;
}

GEN rectdraw(GEN list)
{
  return gnil;
}

GEN buchimag(GEN D, GEN gcbach, GEN gcbach2)
{
  err(bucher13);return gnil;
}

GEN buchreal(GEN D, GEN gsens, GEN gcbach, GEN gcbach2, long prec)
{
  err(bucher13);return gnil;
}

GEN buchgen(GEN P, GEN gcbach, GEN gcbach2, long prec)
{
  err(bucher13);return gnil;
}

GEN buchgenfu(GEN P, GEN gcbach, GEN gcbach2, long prec)
{
  err(bucher13);return gnil;
}

GEN buchinit(GEN P, GEN gcbach, GEN gcbach2, long prec)
{
  err(bucher13);return gnil;
}

GEN buchinitfu(GEN P, GEN gcbach, GEN gcbach2, long prec)
{
  err(bucher13);return gnil;
}

GEN isprincipal(GEN bnf, GEN x)
{
  err(bucher13);return gnil;
}

GEN isunit(GEN bnf, GEN x)
{
  err(bucher13);return gnil;
}

GEN signunit(GEN bignf)
{
  err(bucher13);return gnil;
}
